@@ -7,7 +7,7 @@ import platform
 from .errors import *
 from .utils.aid_bvid_transformer import aid2bvid, bvid2aid
 from .utils.Credential import Credential
-from .utils.Danmaku import Danmaku, DmFontSize, DmMode
+from .utils.Danmaku import Danmaku, DmFontSize, DmMode, SpecialDanmaku
 from .utils.short import get_real_url
 from .utils.sync import sync
 from .utils.network_httpx import get_session, set_session
